# -*- coding: utf-8 -*-

# argument keywords
KW_DT = '_dt'
KW_T = '_t'
KW_I = '_i'
ARG_KEYWORDS = ['_dt', '_t', '_i', '_obj_i', '_pre_i', '_post_i']

# name of the neuron group
NEU_GROUP_TYPE = 'NeuGroup'

# name of the synapse connection
SYN_CONN_TYPE = 'SynConn'

# input operations
INPUT_OPERATIONS = {'-': 'sub',
                    '+': 'add',
                    'x': 'mul',
                    '*': 'mul',
                    '/': 'div',
                    '=': 'assign'}

# model mode
SCALAR_MODE = 'scalar'
VECTOR_MODE = 'vector'
MATRIX_MODE = 'matrix'


